@@ -8,14 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_cloudformation._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-athena", "2.1.1", __name__[0:-6], "cdk-athena@2.1.1.jsii.tgz"
+    "cdk-athena", "3.0.0", __name__[0:-6], "cdk-athena@3.0.0.jsii.tgz"
 )
 
 __all__ = [
